@@ -108,25 +108,8 @@ std::vector<const char*> fileNameList;
 std::vector<cmtk::UniformVolume::SmartPtr> imageListOriginal;
 
 int
-doMain( int argc, char* argv[] )
+doMain( int argc, const char* argv[] )
 {
-#ifdef CMTK_USE_MPI
-#  ifdef CMTK_USE_SMP
-  const int threadLevelSupportedMPI = MPI::Init_thread( argc, argv, MPI::THREAD_FUNNELED );
-  if ( threadLevelSupportedMPI < MPI::THREAD_FUNNELED )
-    {
-    cmtk::StdErr << "WARNING: your MPI implementation does not seem to support THREAD_FUNNELED.\n";
-    }
-#  else
-  MPI::Init( argc, argv );
-#  endif
-#endif
-
-#ifdef CMTK_USE_MPI
-  const int mpiRank = MPI::COMM_WORLD.Get_rank();
-  const int mpiSize = MPI::COMM_WORLD.Get_size();
-#endif
-
   try 
     {
     cmtk::CommandLine cl;
@@ -240,7 +223,7 @@ doMain( int argc, char* argv[] )
       throw cmtk::ExitException( 1 );
       }
     
-    cmtk::ClassStream inStream( fileNameList[0], cmtk::ClassStream::READ );
+    cmtk::ClassStream inStream( fileNameList[0], cmtk::ClassStream::MODE_READ );
     if ( inStream.IsValid() )
       {
       inStream >> *functional;
@@ -260,31 +243,14 @@ doMain( int argc, char* argv[] )
     for ( std::vector<const char*>::const_iterator fnIt = fileNameList.begin(); fnIt != fileNameList.end(); ++fnIt, ++idx )
       {
       cmtk::UniformVolume::SmartPtr nextImage;
-#ifdef CMTK_USE_MPI
-      if ( (idx % mpiSize) == mpiRank )
-#endif
+
+      cmtk::UniformVolume::SmartPtr image( cmtk::VolumeIO::ReadOriented( *fnIt ) );
+      if ( ! image || ! image->GetData() )
 	{
-	cmtk::UniformVolume::SmartPtr image( cmtk::VolumeIO::ReadOriented( *fnIt ) );
-	if ( ! image || ! image->GetData() )
-	  {
-	  cmtk::StdErr << "ERROR: Could not read image " << *fnIt << "\n";
-	  throw cmtk::ExitException( 1 );
-	  }
-	nextImage = image;
+	cmtk::StdErr << "ERROR: Could not read image " << *fnIt << "\n";
+	throw cmtk::ExitException( 1 );
 	}
-      
-#ifdef CMTK_USE_MPI
-      else
-	{
-	cmtk::UniformVolume::SmartPtr image( cmtk::VolumeIO::ReadGridOriented( *fnIt, false ) );
-	if ( ! image )
-	  {
-	  cmtk::StdErr << "ERROR: Could not read image " << *fnIt << "\n";
-	  throw cmtk::ExitException( 1 );
-	  }
-	nextImage = image;
-	}
-#endif
+      nextImage = image;      
       imageListOriginal.push_back( nextImage );
       }
     
@@ -412,23 +378,9 @@ doMain( int argc, char* argv[] )
       }
     }
   
-  // determine and print CPU time (by node, if using MPI)
+  // determine and print CPU time
   const double timeElapsedProcess = cmtk::Timers::GetTimeProcess() - timeBaselineProcess;
-#ifdef CMTK_USE_MPI    
-  std::vector<float> timeElapsedByNodeProcess( mpiSize );
-  MPI::COMM_WORLD.Gather( &timeElapsedProcess, 1, MPI::FLOAT, &timeElapsedByNodeProcess[0], 1, MPI::FLOAT, 0 /*root*/ );
-
-  if ( mpiRank == 0 )
-    {
-    cmtk::StdErr << "Process CPU time [s] by node:\n";
-    for ( int node = 0; node < mpiSize; ++node )
-      {
-      cmtk::StdErr.printf( "%d\t%f\n", node, timeElapsedByNodeProcess[node] );
-      }
-    }
-#else
   cmtk::StdErr.printf( "Process CPU time [s]: %f\n", timeElapsedProcess );  
-#endif  
 
   functional->SetTargetImages( imageListOriginal );
   if ( PreDefinedTemplate )
@@ -454,11 +406,7 @@ doMain( int argc, char* argv[] )
   output.WriteXformsSeparateArchives( OutputStudyListIndividual, PreDefinedTemplatePath );
   output.WriteAverageImage( AverageImagePath, AverageImageInterpolation, UseTemplateData );
 
-#ifdef CMTK_USE_MPI    
-  MPI::Finalize();
-#endif
-
   return 0;
 }
 
-#include "cmtkSafeMainMPI"
+#include "cmtkSafeMain"
