@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3499 $
+//  $Revision: 3642 $
 //
-//  $LastChangedDate: 2011-10-21 12:48:54 -0700 (Fri, 21 Oct 2011) $
+//  $LastChangedDate: 2011-12-21 14:50:10 -0800 (Wed, 21 Dec 2011) $
 //
-//  $LastChangedBy: torsten_at_home $
+//  $LastChangedBy: torstenrohlfing $
 //
 */
 
@@ -258,6 +258,10 @@ DataGrid::SetDims( const Self::IndexType& dims )
   this->m_Dims = dims;
   this->m_CropRegion = this->GetWholeImageRegion();
 
+  this->m_GridIncrements[0] = 1;
+  for ( int i = 1; i < 3; ++i )
+    this->m_GridIncrements[i] = this->m_GridIncrements[i-1] * this->m_Dims[i-1];
+  
   nextI = 1;
   nextJ = nextI * this->m_Dims[0];
   nextK = nextJ * this->m_Dims[1];
