@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3538 $
+//  $Revision: 3646 $
 //
-//  $LastChangedDate: 2011-10-28 16:14:49 -0700 (Fri, 28 Oct 2011) $
+//  $LastChangedDate: 2011-12-22 10:10:55 -0800 (Thu, 22 Dec 2011) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -33,9 +33,12 @@
 #include "cmtkDICOM.h"
 
 #include <Base/cmtkTypedArray.h>
+#include <Base/cmtkSurfaceNormal.h>
 
 #include <System/cmtkConsole.h>
 
+#include <IO/cmtkFileConstHeader.h>
+
 #ifdef CMTK_USE_DCMTK_JPEG
 #  include <djdecode.h>
 #endif
@@ -97,6 +100,120 @@ DICOM::DICOM( const char* path )
     } 
 }
 
+const FixedVector<3,int>
+DICOM::GetDims() const
+{
+  FixedVector<3,int> dims( FixedVector<3,int>::Init( 0 ) );
+
+  Uint16 tempUint16 = 1;
+  if ( this->Document().getValue( DCM_Columns, tempUint16 ) ) 
+    {
+    dims[0] = static_cast<int>( tempUint16 );
+    }
+
+  if ( this->Document().getValue( DCM_Rows, tempUint16 ) ) 
+    {
+    dims[1] = static_cast<int>( tempUint16 );
+    }
+  
+  // detect and treat multi-frame files
+  if ( ! this->Document().getValue( DCM_NumberOfFrames, tempUint16 ) ) 
+    {
+    // unlike Rows/Columns, NumberofFrames defaults to 1
+    tempUint16 = 1;
+    }
+  dims[2] = tempUint16;
+
+  return dims;
+}
+
+const FixedVector<3,double>
+DICOM::GetPixelSize() const
+{
+  FixedVector<3,double> pixelSize( FixedVector<3,double>::Init( 0.0 ) );
+  
+  // get calibration from image
+  const bool hasPixelSpacing = (this->Document().getValue(DCM_PixelSpacing, pixelSize[0], 0) > 0);
+  if ( hasPixelSpacing )
+    {
+    if (this->Document().getValue(DCM_PixelSpacing, pixelSize[1], 1) < 2) 
+      {
+      throw Exception( "DICOM file does not have two elements in pixel size tag" );
+      }
+    } 
+  else
+    throw Exception( "DICOM file does not specify pixel size" );
+
+  // get slice spacing from multi-slice images.
+  if ( ! this->Document().getValue( DCM_SpacingBetweenSlices, pixelSize[2] ) )
+    {
+    pixelSize[2] = 0;
+    }
+
+  return pixelSize;
+}    
+    
+const FixedVector<3,double>
+DICOM::GetImageOrigin() const
+{
+  FixedVector<3,double> imageOrigin( FixedVector<3,double>::Init( 0.0 ) );
+
+  const char *image_position_s = NULL;
+  if ( ! this->Document().getValue( DCM_ImagePositionPatient, image_position_s ) ) 
+    {
+    // ImagePositionPatient tag not present, try ImagePosition instead
+#ifdef DCM_ImagePosition
+    this->Document().getValue( DCM_ImagePosition, image_position_s );
+#else
+    this->Document().getValue( DCM_ACR_NEMA_ImagePosition, image_position_s );
+#endif
+    }
+  if ( image_position_s ) 
+    {
+    double xyz[3];
+    if ( 3 == sscanf( image_position_s,"%20lf%*c%20lf%*c%20lf", xyz, xyz+1, xyz+2 ) ) 
+      {
+      imageOrigin = FixedVector<3,double>( xyz );
+      }
+    }
+  
+  return imageOrigin;
+}
+
+const FixedVector< 2, FixedVector<3,double> > 
+DICOM::GetImageOrientation() const
+{
+  FixedVector< 2, FixedVector<3,double> > orientation;
+  
+  orientation[0] = FixedVector<3,double>( FixedVector<3,double>::Init( 0.0 ) );
+  orientation[1] = FixedVector<3,double>( FixedVector<3,double>::Init( 0.0 ) );
+
+  orientation[0][0] = 1;
+  orientation[1][1] = 1;
+  
+  const char *image_orientation_s = NULL;
+#ifdef DCM_ImageOrientation
+  if ( ! this->Document().getValue( DCM_ImageOrientation, image_orientation_s ) )
+#else
+    if ( ! this->Document().getValue( DCM_ACR_NEMA_ImageOrientation, image_orientation_s ) )
+#endif
+      {
+      // ImageOrientation tag not present, try ImageOrientationPatient instead
+      this->Document().getValue( DCM_ImageOrientationPatient, image_orientation_s );
+      }
+  if ( image_orientation_s ) 
+    {
+    double dx[3], dy[3];
+    if ( 6 == sscanf( image_orientation_s, "%20lf%*c%20lf%*c%20lf%*c%20lf%*c%20lf%*c%20lf", dx, dx+1, dx+2, dy, dy+1, dy+2 ) ) 
+      {
+      orientation[0] = ( FixedVector<3,double>( dx ) );
+      orientation[1] = ( FixedVector<3,double>( dy ) );
+      }
+    }
+
+  return orientation;
+}
+
 TypedArray::SmartPtr
 DICOM::GetPixelDataArray( const size_t pixelDataLength )
 {
@@ -195,6 +312,110 @@ DICOM::GetPixelDataArray( const size_t pixelDataLength )
 }
 
 
+const FixedVector<3,double>
+DICOM::DemosaicAndGetNormal( const FixedVector< 2, FixedVector<3,double> >& imageOrientation, FixedVector<3,int>& dims, TypedArray::SmartPtr& pixelDataArray )
+{
+  // without further information, we "guess" the image normal vector
+  FixedVector<3,double> sliceNormal = SurfaceNormal( imageOrientation[0], imageOrientation[1] ).Get();
+  
+  // detect and treat Siemens multi-slice mosaics
+  const char* tmpStr = NULL;
+  if ( this->Document().getValue( DCM_Manufacturer, tmpStr ) )
+    {
+    if ( !strncmp( tmpStr, "SIEMENS", 7 ) )
+      {
+      Uint16 tempUint16 = 0;
+      const DcmTagKey nSlicesTag(0x0019,0x100a);
+      if ( this->Document().getValue( nSlicesTag, tempUint16 ) )
+	{
+	dims[2] = tempUint16;
+	
+	const DcmTagKey mosaicTag(0x0051,0x100b);
+	if ( this->Document().getValue( mosaicTag, tmpStr ) )
+	  {
+	  int rows;
+	  int cols;
+	  if ( 2 != sscanf( tmpStr, "%dp*%ds", &rows, &cols) )
+	    {
+	    if ( 2 != sscanf( tmpStr, "%d*%ds", &rows, &cols) )
+	      {
+	      StdErr << "ERROR: unable to parse mosaic size from " << tmpStr << "\n";
+	      }
+	    }
+	  
+	  if ( (cols > 0) && (rows > 0 ) )
+	    {
+	    const int xMosaic = dims[0] / cols;
+	    
+	    dims[0] = cols;
+	    dims[1] = rows;
+	    
+	    // de-mosaic the data array
+	    const unsigned long imageSizePixels = dims[0] * dims[1] * dims[2];
+	    TypedArray::SmartPtr newDataArray( TypedArray::Create( pixelDataArray->GetType(), imageSizePixels ) );
+	    
+	    const size_t pixelsPerSlice = cols * rows;
+	    size_t toOffset = 0;
+	    for ( int slice = 0; slice < dims[2]; ++slice )
+	      {
+	      for ( int j = 0; j < rows; ++j, toOffset += dims[0] )
+		{
+		const size_t iPatch = slice % xMosaic;
+		const size_t jPatch = slice / xMosaic;
+		
+		const size_t fromOffset = jPatch * xMosaic * pixelsPerSlice + j * xMosaic * cols + iPatch * cols;
+		pixelDataArray->BlockCopy( *newDataArray, toOffset, fromOffset, cols );
+		}
+	      }
+	    
+	    pixelDataArray = newDataArray;
+	    }
+	  
+// For the following, see here: http://nipy.sourceforge.net/nibabel/dicom/siemens_csa.html#csa-header
+	  const DcmTagKey csaHeaderInfoTag(0x0029,0x1010);
+	  
+	  const Uint8* csaHeaderInfo = NULL;
+	  unsigned long csaHeaderLength = 0;
+	  this->Dataset().findAndGetUint8Array ( csaHeaderInfoTag, csaHeaderInfo, &csaHeaderLength );
+	  
+	  FileConstHeader fileHeader( csaHeaderInfo, false /*isBigEndian*/ ); // Siemens CSA header is always little endian
+	  const size_t nTags = fileHeader.GetField<Uint32>( 8 );
+	  
+	  size_t tagOffset = 16; // start after header
+	  for ( size_t tag = 0; tag < nTags; ++tag )
+	    {
+	    char tagName[65];
+	    fileHeader.GetFieldString( tagOffset, tagName, 64 );
+//	  StdErr << tag << "\t" << tagName << "\n";
+	    
+	    const size_t nItems = fileHeader.GetField<Uint32>( tagOffset + 76 );
+//	  StdErr << "  nItems: " << nItems << "\n";
+	    
+	    tagOffset += 84;
+	    for ( size_t item = 0; item < nItems; ++item )
+	      {
+	      const size_t itemLen = fileHeader.GetField<Uint32>( tagOffset );
+	      
+//	    StdErr << "    len: " << itemLen << "\n";
+	      
+	      if ( ! strcmp( tagName, "SliceNormalVector" ) && (item < 3) )
+		{
+		char valStr[65];
+		sliceNormal[item] = atof( fileHeader.GetFieldString( tagOffset+16, valStr, 64 ) );
+		
+//	      StdErr << "    " << valStr << "\n";
+		}
+	      
+	      tagOffset += 4*((itemLen+3)/4) /*move up to nearest 4-byte boundary*/ + 16 /*the 4 ints at the beginning of item, including itemLength*/;
+	      }
+	    }
+	  }
+	}
+      }  
+    }
+  return sliceNormal;
+}
+
 ScalarImage* 
 DICOM::Read 
 ( const char *path )
@@ -203,40 +424,19 @@ DICOM::Read
 
   Self dicom( path );
 
-  Uint16 dimsX, dimsY;
-  if ( ! ( dicom.Document().getValue( DCM_Columns, dimsX ) && dicom.Document().getValue( DCM_Rows, dimsY ) ) ) 
-    {
-    StdErr << "ERROR: File " << path << " has no DCM_Columns/DCM_Rows tags.\n";
-    return NULL; // no image dimensions, nothing we can do.
-    }
+  FixedVector<3,int> dims = dicom.GetDims();
+  FixedVector<3,double> pixelSize = dicom.GetPixelSize();
+  ScalarImage::SpaceVectorType imageOrigin = dicom.GetImageOrigin();
+
+  image = new ScalarImage( dims[0], dims[1], dims[2] );
+  image->SetPixelSize( pixelSize[0], pixelSize[1] );
+  image->SetFrameToFrameSpacing( pixelSize[2] );
   
-  Uint16 numberOfFrames = 1;
-  if ( ! dicom.Document().getValue( DCM_NumberOfFrames, numberOfFrames ) )
-    numberOfFrames = 1;
-  image = new ScalarImage( dimsX, dimsY, numberOfFrames );
-  
-  // get calibration from image
-  double calibrationX = -1, calibrationY = -1;
-  bool hasPixelSpacing = (dicom.Document().getValue(DCM_PixelSpacing, calibrationX, 0) > 0);
-  if ( hasPixelSpacing ) 
-    {
-    if ( dicom.Document().getValue(DCM_PixelSpacing, calibrationY, 1) < 2)
-      calibrationY = calibrationX;
-    } 
-  else
-    calibrationX = calibrationY = -1;
-  image->SetPixelSize( calibrationX, calibrationY );
-  
-  TypedArray::SmartPtr pixelDataArray = dicom.GetPixelDataArray( dimsX * dimsY * numberOfFrames );
+  TypedArray::SmartPtr pixelDataArray = dicom.GetPixelDataArray( dims[0] * dims[1] * dims[2] );
   image->SetPixelData( pixelDataArray );
 
   // now some more manual readings...
 
-    // get slice spacing from multi-slice images.
-  double frameToFrame = 0;
-  if ( dicom.Document().getValue( DCM_SpacingBetweenSlices, frameToFrame ) )
-    image->SetFrameToFrameSpacing( frameToFrame );
-
     // get original table position from image.
   double sliceLocation = 0;
   if ( ! dicom.Document().getValue( DCM_SliceLocation, sliceLocation ) ) 
@@ -248,54 +448,12 @@ DICOM::Read
 #endif
     }
   image->SetImageSlicePosition( sliceLocation );
-  
-  // Use table position to set image position as long as we don't know
-  // better.
-  ScalarImage::SpaceVectorType imageOrigin( ScalarImage::SpaceVectorType::Init( 0 ) );
-  imageOrigin[2] = sliceLocation;
-      
-  // get original image position from file.
-  const char *image_position_s = NULL;
-  if ( ! dicom.Document().getValue( DCM_ImagePositionPatient, image_position_s ) ) 
-    {
-    // ImagePositionPatient tag not present, try ImagePosition instead
-#ifdef DCM_ImagePosition
-    dicom.Document().getValue( DCM_ImagePosition, image_position_s );
-#else
-    dicom.Document().getValue( DCM_ACR_NEMA_ImagePosition, image_position_s );
-#endif
-    }
-  if ( image_position_s ) 
-    {
-    double xyz[3];
-    if ( 3 == sscanf( image_position_s,"%lf%*c%lf%*c%lf", xyz, xyz+1, xyz+2 ) ) 
-      {
-      imageOrigin = ScalarImage::SpaceVectorType( xyz );
-      }
-    }
-  
   image->SetImageOrigin( imageOrigin );
   
   // get original image direction from file.
-  ScalarImage::SpaceVectorType imageDirectionX( ScalarImage::SpaceVectorType::Init(0) );
-  imageDirectionX[0] = 1;
-  ScalarImage::SpaceVectorType imageDirectionY( ScalarImage::SpaceVectorType::Init(0) );
-  imageDirectionY[1] = 1;
-
-  const char *image_orientation_s = NULL;
-  dicom.Document().getValue( DCM_ImageOrientationPatient, image_orientation_s );
-  if ( image_orientation_s ) 
-    {
-    double dx[3], dy[3];
-    if ( 6 == sscanf( image_orientation_s, "%lf%*c%lf%*c%lf%*c%lf%*c%lf%*c%lf", dx, dx+1, dx+2, dy, dy+1, dy+2 ) ) 
-      {
-      imageDirectionX = ScalarImage::SpaceVectorType( dx );
-      imageDirectionY = ScalarImage::SpaceVectorType( dy );
-      }
-    }
-  
-  image->SetImageDirectionX( imageDirectionX );
-  image->SetImageDirectionY( imageDirectionY );
+  FixedVector< 2, FixedVector<3,double> > imageOrientation = dicom.GetImageOrientation();
+  image->SetImageDirectionX( imageOrientation[0] );
+  image->SetImageDirectionY( imageOrientation[1] );
 
   return image;
 }
