@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3002 $
+//  $Revision: 3647 $
 //
-//  $LastChangedDate: 2011-03-17 10:23:38 -0700 (Thu, 17 Mar 2011) $
+//  $LastChangedDate: 2011-12-22 10:49:31 -0800 (Thu, 22 Dec 2011) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -83,14 +83,14 @@ XformIO::Read( const char* path )
     {
     DebugOutput( 1 ) << "Reading transformation from typedstream file " << realPath << "\n";
     
-    ClassStream stream( realPath, ClassStream::READ );
+    ClassStream stream( realPath, ClassStream::MODE_READ );
     WarpXform* warpXform;
     stream >> warpXform;
     
     if ( warpXform ) 
       return Xform::SmartPtr( warpXform );
     
-    stream.Open( realPath, ClassStream::READ );
+    stream.Open( realPath, ClassStream::MODE_READ );
     try
       {
       AffineXform affineXform;
@@ -151,7 +151,7 @@ XformIO::Write
     }
     case FILEFORMAT_TYPEDSTREAM:
     {
-    ClassStream stream( absolutePath, ClassStream::WRITE );
+    ClassStream stream( absolutePath, ClassStream::MODE_WRITE );
     
     const AffineXform* affineXform = dynamic_cast<const AffineXform*>( xform );
     if ( affineXform )
