@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3193 $
+//  $Revision: 3672 $
 //
-//  $LastChangedDate: 2011-04-28 16:15:14 -0700 (Thu, 28 Apr 2011) $
+//  $LastChangedDate: 2011-12-23 12:56:49 -0800 (Fri, 23 Dec 2011) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -2162,7 +2162,7 @@ lbfgsbminimize
   ap::boolean_1d_array lsave;
   ap::integer_1d_array isave;
   ap::real_1d_array dsave;
-  int task;
+  int task = 0;
   bool prjctd;
   bool cnstnd;
   bool boxed;
