@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3499 $
+//  $Revision: 3700 $
 //
-//  $LastChangedDate: 2011-10-21 12:48:54 -0700 (Fri, 21 Oct 2011) $
+//  $LastChangedDate: 2012-01-06 16:28:06 -0800 (Fri, 06 Jan 2012) $
 //
-//  $LastChangedBy: torsten_at_home $
+//  $LastChangedBy: torstenrohlfing $
 //
 */
 
@@ -237,12 +237,12 @@ ImagePairAffineRegistrationCommandLine
     inStudylist = clArg1;
     if ( InitialStudylist ) 
       {
-      StdErr << "Transformation will be overriden by '--initial' list.\n";
+      StdErr << "WARNING: transformation of input studylist will be overriden by transformation provided with '--initial'.\n";
       }
     
     DebugOutput( 1 ) << "Reading input studylist " << inStudylist << ".\n";
     
-    ClassStream typedStream( MountPoints::Translate(inStudylist), "registration", ClassStream::READ );
+    ClassStream typedStream( MountPoints::Translate(inStudylist), "registration", ClassStream::MODE_READ );
     if ( ! typedStream.IsValid() ) 
       {
       StdErr << "ERROR: could not open studylist archive " << inStudylist << ".\n";
@@ -384,7 +384,7 @@ ImagePairAffineRegistrationCommandLine::OutputResultParameters
 void
 ImagePairAffineRegistrationCommandLine::OutputResultList( const char* studyList ) const
 {
-  ClassStream classStream( studyList, "studylist", ClassStream::WRITE );
+  ClassStream classStream( studyList, "studylist", ClassStream::MODE_WRITE );
   if ( !classStream.IsValid() ) return;
   
   classStream.Begin( "studylist" );
@@ -401,7 +401,7 @@ ImagePairAffineRegistrationCommandLine::OutputResultList( const char* studyList
     
   classStream.Close();
     
-  classStream.Open( studyList, "registration", ClassStream::WRITE );
+  classStream.Open( studyList, "registration", ClassStream::MODE_WRITE );
     
   classStream.Begin( "registration" );
   classStream.WriteString( "reference_study", CompressedStream::GetBaseName( Study1 ) );
@@ -412,7 +412,7 @@ ImagePairAffineRegistrationCommandLine::OutputResultList( const char* studyList
   classStream.End();
   classStream.Close();
     
-  classStream.Open( studyList, "settings", ClassStream::WRITE );
+  classStream.Open( studyList, "settings", ClassStream::MODE_WRITE );
   classStream.WriteDouble( "exploration", this->m_MaxStepSize );
   classStream.WriteDouble( "accuracy", this->m_MinStepSize );
   classStream.WriteDouble( "min_sampling", this->m_Sampling );
@@ -426,7 +426,7 @@ ImagePairAffineRegistrationCommandLine::OutputResultList( const char* studyList
 
   classStream.Close();
     
-  classStream.Open( studyList, "statistics", ClassStream::WRITE );
+  classStream.Open( studyList, "statistics", ClassStream::MODE_WRITE );
   classStream.WriteDouble( "time", this->GetTotalElapsedTime() );
   classStream.WriteDouble( "walltime", this->GetTotalElapsedWalltime() );
 #ifdef CMTK_USE_PTHREADS
