@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3281 $
+//  $Revision: 3608 $
 //
-//  $LastChangedDate: 2011-07-26 14:38:18 -0700 (Tue, 26 Jul 2011) $
+//  $LastChangedDate: 2011-12-02 10:47:18 -0800 (Fri, 02 Dec 2011) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -634,8 +634,4 @@ ReformatVolume::CreateInterpolator
 
 } // end namespace cmtk
 
-#ifdef CMTK_USE_MPI
-#  include "cmtkReformatVolumeMPI.txx"
-#else
-#  include "cmtkReformatVolume.txx"
-#endif
+#include "cmtkReformatVolume.txx"
